#
# spec file for package SDL2
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           SDL2
%define lname   libSDL2-2_0-0
Version:        2.0.8
Release:        lp151.4.3.1
Summary:        Simple DirectMedia Layer Library
License:        Zlib
Group:          Development/Libraries/X11
Url:            http://libsdl.org/

#DL-URL:        http://libsdl.org/download-2.0.php
Source:         http://libsdl.org/release/%name-%version.tar.gz
Source2:        http://libsdl.org/release/%name-%version.tar.gz.sig
Source3:        %name.keyring
Source4:        baselibs.conf
Patch1:         sdl2-symvers.patch
Patch2:         CVE-2019-7577.patch
Patch4:         CVE-2019-7575.patch
Patch5:         CVE-2019-7574.patch
Patch6:         CVE-2019-7572.patch
Patch7:         CVE-2019-7578.patch
Patch8:         CVE-2019-7635.patch
Patch9:         CVE-2019-7636.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  nasm
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(alsa) >= 0.9.0
BuildRequires:  pkgconfig(dbus-1)
%if !0%{?sle_version}
BuildRequires:  pkgconfig(fcitx)
%endif
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glesv1_cm)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(ibus-1.0)
BuildRequires:  pkgconfig(ice)
# KMS/DRM driver needs libdrm and libgbm
BuildRequires:  pkgconfig(gbm) >= 9.0.0
BuildRequires:  pkgconfig(libdrm) >= 2.4.46
%if 0%{?suse_version} > 1220
BuildRequires:  pkgconfig(tslib)
%endif
BuildRequires:  pkgconfig(libpulse-simple) >= 0.9
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xscrnsaver)
BuildRequires:  pkgconfig(xxf86vm)

%description
This is the "Simple DirectMedia Layer" library. It provides a generic
API for access to audio, keyboard, mouse, and display framebuffer
across multiple platforms.

%package -n %lname
Summary:        Simple DirectMedia Layer Library
Group:          System/Libraries
Provides:       SDL2 = %version-%release

%description -n %lname
This is the "Simple DirectMedia Layer" library. It provides a generic
API for access to audio, keyboard, mouse, and display framebuffer
across multiple platforms.

%package -n libSDL2-devel
Summary:        SDL2 Library Developer Files
Group:          Development/Libraries/X11
Requires:       %lname = %version
Requires:       c_compiler
Requires:       pkgconfig
Requires:       pkgconfig(gl)
Requires:       pkgconfig(glesv1_cm)
Requires:       pkgconfig(glesv2)
Requires:       pkgconfig(glu)
Requires:       pkgconfig(x11)
Requires:       pkgconfig(xproto)
Provides:       SDL2-devel = %version-%release

%description -n libSDL2-devel
This package contains files needed for development with the SDL2
library.

%prep
%setup -q
%patch -P 1 -p1
%patch2 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
dos2unix WhatsNew.txt
dos2unix TODO.txt
dos2unix BUGS.txt
dos2unix README-SDL.txt
dos2unix README.txt
dos2unix CREDITS.txt
dos2unix COPYING.txt

%build
# In this instance, we do want --with-pic because of libSDL2main.a.
%configure --with-pic --disable-alsa-shared --disable-video-directfb \
	--enable-video-kmsdrm --enable-video-wayland \
%if 0%{?sle_version}
	--disable-fcitx \
%endif
%ifarch ix86
	--enable-sse2=no \
%endif
	--enable-sse3=no \
	--disable-rpath
make %{?_smp_mflags} V=1

%install
make install DESTDIR="%buildroot"
rm -f "%buildroot/%_libdir"/*.la
# We do not want static libs, but using --disable-static leads to make aborting
# halfway through. SDL2main.a we need to keep(?) for the stub symbol.
find "%buildroot/%_libdir" -type f -name "*.a" ! -name "libSDL2main.a" -delete

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%doc BUGS.txt COPYING.txt CREDITS.txt README.txt README-SDL.txt
%_libdir/libSDL2-2*.so.*

%files -n libSDL2-devel
%defattr(-,root,root)
%doc TODO.txt WhatsNew.txt
%_bindir/sdl2-config
%_libdir/libSDL2.so
%_libdir/libSDL2main.a
%_includedir/SDL2/
%_datadir/aclocal/sdl2.m4
%_libdir/pkgconfig/sdl2.pc
%_libdir/cmake/SDL2/

%changelog
* Thu May 23 2019 Qiang Zheng <qzheng@suse.com>
- Remove CVE-2019-7637.patch, the modification of function
  SDL_CalculatePitch is only suit for SDL not SDL2.
* Wed Mar 20 2019 qzheng <qzheng@suse.com>
- Add CVE-2019-7636.patch to fix a heap-based buffer over-read
  issue (CVE-2019-7636, boo#1124826, CVE-2019-7638, boo#1124824).
* Wed Mar 20 2019 qzheng <qzheng@suse.com>
- Add CVE-2019-7635.patch to fix a heap-based buffer over-read
  issue (CVE-2019-7635, boo#1124827).
* Wed Mar 20 2019 qzheng <qzheng@suse.com>
- Add CVE-2019-7578.patch to fix a heap-based buffer over-read
  issue (CVE-2019-7578, boo#1125099, CVE-2019-7576, boo#1124799
  CVE-2019-7573, boo#1124805).
* Wed Mar 20 2019 qzheng <qzheng@suse.com>
- Add CVE-2019-7572.patch to fix a buffer over-read issue
  (CVE-2019-7572, boo#1124806).
* Wed Mar 20 2019 qzheng <qzheng@suse.com>
- Add CVE-2019-7574.patch to fix a heap-based buffer over-read
  issue (CVE-2019-7574, boo#1124803).
* Thu Feb 28 2019 qzheng <qzheng@suse.com>
- Add CVE-2019-7575.patch to fix a heap-based buffer overflow
  issue (CVE-2019-7575, boo#1124802).
* Thu Feb 28 2019 qzheng <qzheng@suse.com>
- Add CVE-2019-7637.patch to fix a heap-base buffer overflow
  issue (CVE-2019-7637, boo#1124825).
* Wed Feb 27 2019 qzheng <qzheng@suse.com>
- Add CVE-2019-7577.patch to fix a buffer over-read issue
  (CVE-2019-7577, boo#1124800).
* Sat Mar 17 2018 ytz1995@hotmail.com
- Build with Wayland support
* Thu Mar  8 2018 jengelh@inai.de
- Update to new upstream release 2.0.8
  * Added SDL_fmod() and SDL_log10().
  * Each of the SDL math functions now has the corresponding
    float version.
  * Added SDL_SetYUVConversionMode() and
    SDL_GetYUVConversionMode() to control the formula used when
    converting to and from YUV colorspace. The options are JPEG,
    BT.601, and BT.709.
  * Added the hint SDL_HINT_VIDEO_X11_NET_WM_BYPASS_COMPOSITOR to
    control whether the X server should skip the compositor for
    the SDL application. This defaults to "1".
  * Added the hint SDL_HINT_VIDEO_DOUBLE_BUFFER to control
    whether the Raspberry Pi and KMSDRM video drivers should use
    double or triple buffering (the default).
* Wed Jan 10 2018 jengelh@inai.de
- Add sdl2-symvers.patch.
* Sat Oct 28 2017 adam@mizerski.pl
- update to 2.0.7
  * Added audio stream conversion functions.
  * Added functions to query and set the SDL memory allocation
    functions.
  * Added locking functions for multi-threaded access to
    the joystick and game controller APIs.
  * Some functions are now thread-safe.
- removed patches, merged upstream
  * dbus.diff
  * SDL2-ppc64-declaration-after-statement.patch
  * SDL-bnc1062784-check-overflow-xcf-props.patch
* Thu Oct 19 2017 sreeves@suse.com
- Add SDL-bnc1062784-check-overflow-xcf-props.patch. CVE-2017-2888
* Mon Oct 16 2017 wbauer@tmo.at
- Disable SSE3 (and also SSE2 on ix86) to prevent crashes on older
  CPUs that don't support these instructions
* Mon Oct  2 2017 jengelh@inai.de
- Add dbus.diff
* Mon Oct  2 2017 guillaume@opensuse.org
- Enable KMS/DRM video driver
* Sat Sep 30 2017 spartanj@gmail.com
- Update to new upstream release 2.0.6
  * Added Vulkan graphics support in SDL_vulkan.h.
  * Added SDL_ComposeCustomBlendMode() to create custom blend
    modes for 2D rendering.
  * Added support for many game controllers, including the
    Nintendo Switch Pro Controller.
  * Added support for inverted axes and separate axis directions
    in game controller mappings.
  * Added functions to return information about joysticks and
    open game controllers.
  * Added SDL_GameControllerNumMappings() and
    SDL_GameControllerMappingForIndex() to be able to enumerate
    the built-in game controller mappings.
  * Added SDL_LoadFile() and SDL_LoadFile_RW() to load a file
    into memory.
  * Added SDL_DuplicateSurface() to make a copy of a surface.
  * Added an experimental JACK audio driver.
  * Implemented non-power-of-two audio resampling.
  * Added the hint SDL_HINT_AUDIO_RESAMPLING_MODE to control the
    quality of resampling.
  * Added the hint SDL_HINT_RENDER_LOGICAL_SIZE_MODE to control
    the scaling policy for SDL_RenderSetLogicalSize().
  * Added the hints SDL_HINT_MOUSE_NORMAL_SPEED_SCALE and
    SDL_HINT_MOUSE_RELATIVE_SPEED_SCALE to scale the mouse speed
    when being read from raw mouse input.
  * Added the hint SDL_HINT_TOUCH_MOUSE_EVENTS to control whether
    SDL will synthesize mouse events from touch events.
  * Added an experimental KMS/DRM video driver for embedded
    development.
- Remove dbus-ime.diff (no longer needed)
* Tue Aug  1 2017 fcrozat@suse.com
- Do not BuildRequires pkgconfig(fcitx) on SLE (not shipped anymore
  since SLE12 SP2).
* Thu Jun 29 2017 schwab@suse.de
- libspe2 doesn't exist any more
* Wed Feb 15 2017 jengelh@inai.de
- Add dbus-ime.diff and build with fcitx [boo#1025413]
* Sun Oct 23 2016 aloisio@gmx.com
- Backported commit 5184186d4366 and fbf9b0e3589a as
  SDL2-ppc64-declaration-after-statement.patch to fix build
  on ppc64/ppc64le
* Thu Oct 20 2016 aloisio@gmx.com
- Update to 2.0.5
  General:
  * Implemented audio capture support for some platforms
  * Added SDL_DequeueAudio() to retrieve audio when buffer
    queuing is turned on for audio capture
  * Added events for dragging and dropping text
  * Added events for dragging and dropping multiple items
  * By default the click raising a window will not be
    delivered to the SDL application. You can set the hint
    SDL_HINT_MOUSE_FOCUS_CLICKTHROUGH to "1" to allow that click
    through to the window.
  * Saving a surface with an alpha channel as a BMP will use a
    newer BMP format that supports alpha information. You can
    set the hint SDL_HINT_BMP_SAVE_LEGACY_FORMAT to "1" to use
    the old format.
  * Added SDL_GetHintBoolean() to get the boolean value of a
    hint
  * Added SDL_RenderSetIntegerScale() to set whether to
    smoothly scale or use integral multiples of the viewport
    size when scaling the rendering output
  * Added SDL_CreateRGBSurfaceWithFormat() and
    SDL_CreateRGBSurfaceWithFormatFrom() to create an SDL
    surface with a specific pixel format
  * Added SDL_GetDisplayUsableBounds() which returns the area
    usable for windows. For example, on Mac OS X, this subtracts
    the area occupied by the menu bar and dock.
  * Added SDL_GetWindowBordersSize() which returns the size of
    the window's borders around the client area
  * Added a window event SDL_WINDOWEVENT_HIT_TEST when a
    window had a hit test that wasn't SDL_HITTEST_NORMAL (e.g.
    in the title bar or window frame)
  * Added SDL_SetWindowResizable() to change whether a window
    is resizable
  * Added SDL_SetWindowOpacity() and SDL_GetWindowOpacity() to
    affect the window transparency
  * Added SDL_SetWindowModalFor() to set a window as modal for
    another window
  * Added support for AUDIO_U16LSB and AUDIO_U16MSB to
    SDL_MixAudioFormat()
  * Fixed flipped images when reading back from target
    textures when using the OpenGL renderer
  * Fixed texture color modulation with SDL_BLENDMODE_NONE
    when using the OpenGL renderer
  * Fixed bug where the alpha value of colorkeys was ignored
    when blitting in some cases
  Linux:
  * Added support for the Fcitx IME
  * Added a window event SDL_WINDOWEVENT_TAKE_FOCUS when a
    window manager asks the SDL window whether it wants to take
    focus.
  * Refresh rates are now rounded instead of truncated, e.g.
    59.94 Hz is rounded up to 60 Hz instead of 59.
  * Added initial support for touchscreens on Raspberry Pi
* Thu Mar 17 2016 mpluskal@suse.com
- Make building more verbose
* Thu Mar 10 2016 jengelh@inai.de
- Enable udev support
* Sun Jan 10 2016 mailaender@opensuse.org
- update to version 2.0.4
  General:
  * Added support for web applications using Emscripten, see
    docs/README-emscripten.md for more information
  * Added support for web applications using Native Client (NaCl), see
    docs/README-nacl.md for more information
  * Added an API to queue audio instead of using the audio callback:
    SDL_QueueAudio(), SDL_GetQueuedAudioSize(), SDL_ClearQueuedAudio()
  * Added events for audio device hot plug support:
    SDL_AUDIODEVICEADDED, SDL_AUDIODEVICEREMOVED
  * Added SDL_PointInRect()
  * Added SDL_HasAVX2() to detect CPUs with AVX2 support
  * Added SDL_SetWindowHitTest() to let apps treat parts of their SDL window
    like traditional window decorations (drag areas, resize areas)
  * Added SDL_GetGrabbedWindow() to get the window that currently has input
    grab, if any
  * Added SDL_RenderIsClipEnabled() to tell whether clipping is currently
    enabled in a renderer
  * Added SDL_CaptureMouse() to capture the mouse to get events while the
    mouse is not in your window
  * Added SDL_WarpMouseGlobal() to warp the mouse cursor in global screen
    space
  * Added SDL_GetGlobalMouseState() to get the current mouse state outside of
    an SDL window* Added a direction field to mouse wheel events to tell
    whether they are flipped (natural) or not
  * Added GL_CONTEXT_RELEASE_BEHAVIOR GL attribute (maps to
    [WGL|GLX]_ARB_context_flush_control extension)
  * Added EGL_KHR_create_context support to allow OpenGL ES version selection
    on some platforms* Added NV12 and NV21 YUV texture support for OpenGL and
    OpenGL ES 2.0 renderers
  * Added a Vivante video driver that is used on various SoC platforms
  * Added an event SDL_RENDER_DEVICE_RESET that is sent from the D3D
    renderers when the D3D device is lost, and from Android's event loop when
    the GLES context had to be recreated
  * Added a hint SDL_HINT_NO_SIGNAL_HANDLERS to disable SDL's built in signal
    handling* Added a hint SDL_HINT_THREAD_STACK_SIZE to set the stack size of
    SDL's threads
  * Added SDL_sqrtf(), SDL_tan(), and SDL_tanf() to the stdlib routines
  * Improved support for WAV and BMP files with unusual chunks in them
  * Renamed SDL_assert_data to SDL_AssertData and SDL_assert_state to
    SDL_AssertState
  * Added a hint SDL_HINT_WINDOW_FRAME_USABLE_WHILE_CURSOR_HIDDEN to prevent
    window interaction while cursor is hidden
  * Added SDL_GetDisplayDPI() to get the DPI information for a display* Added
    SDL_JoystickCurrentPowerLevel() to get the battery level of a joystick
  * Added SDL_JoystickFromInstanceID(), as a helper function, to get the
    SDL_Joystick* that an event is referring to.
  * Added SDL_GameControllerFromInstanceID(), as a helper function, to get
    the SDL_GameController* that an event is referring to.
* Mon Jan 12 2015 schwab@suse.de
- libspe2 only exists for ppc and ppc64
* Fri Dec 19 2014 jengelh@inai.de
- Drop old arts/esound soundserver support.
* Thu Dec 18 2014 jengelh@inai.de
- Remove SDL2 obsoletes (we never had packages of that name).
  Copy current Provides to baselibs.conf.
* Mon Jul 21 2014 jengelh@inai.de
- Update to new upstream release 2.0.3
  * This is a minor bugfix release to take care of creating an OpenGL
  context on Mac OS X.
* Mon May 26 2014 mailaender@opensuse.org
- Added missing build dependencies
  * arts
  * dbus
  * udev
  * tslib
- Removed unrecognized options: --disable-video-svga, --disable-video-ps3
* Mon May 26 2014 mailaender@opensuse.org
- Use pkgconfig everywhere
- Fix the build on SLE using prjconf
* Thu Mar 13 2014 mailaender@opensuse.org
- Update to 2.0.2
  * Added SDL_GL_ResetAttributes() to reset OpenGL attributes to default values
  * Added an API to load a database of game controller mappings from a file:
    SDL_GameControllerAddMappingsFromFile(), SDL_GameControllerAddMappingsFromRW()
  * Added game controller mappings for the PS4 and OUYA controllers
  * Added SDL_GetDefaultAssertionHandler() and SDL_GetAssertionHandler()
  * Added SDL_DetachThread()
  * Added SDL_HasAVX() to determine if the CPU has AVX features
  * Added SDL_vsscanf(), SDL_acos(), and SDL_asin() to the stdlib routines
  * EGL can now create/manage OpenGL and OpenGL ES 1.x/2.x contexts, and share
    them using SDL_GL_SHARE_WITH_CURRENT_CONTEXT
  * Added a field "clicks" to the mouse button event which records whether the event is a single click, double click, etc.
  * The screensaver is now disabled by default, and there is a hint SDL_HINT_VIDEO_ALLOW_SCREENSAVER that can change that behavior.
  * Added a hint SDL_HINT_MOUSE_RELATIVE_MODE_WARP to specify whether mouse relative mode should be emulated using mouse warping.
  * testgl2 does not need to link with libGL anymore
  * Added testgles2 test program to demonstrate working with OpenGL ES 2.0
  * Added controllermap test program to visually map a game controller
  * Fixed fullscreen and focused behavior when receiving NotifyGrab events
  * Added experimental Wayland and Mir support, disabled by default
- Added SDL2-devel provides
* Thu Nov  7 2013 mailaender@opensuse.org
- Update to version 2.0.1:
  * Added an API to get common filesystem paths in SDL_filesystem.h:
    SDL_GetBasePath(), SDL_GetPrefPath()
  * Added an API to do optimized YV12 and IYUV texture updates:
    SDL_UpdateYUVTexture()
  * Added an API to get the amount of RAM on the system:
    SDL_GetSystemRAM()
  * Added a macro to perform timestamp comparisons with SDL_GetTicks():
    SDL_TICKS_PASSED()
  * Dramatically improved OpenGL ES 2.0 rendering performance
  * Added OpenGL attribute SDL_GL_FRAMEBUFFER_SRGB_CAPABLE
  * Fixed float audio support with the PulseAudio driver
  * Fixed missing line endpoints in the OpenGL renderer on some drivers
  * X11 symbols are no longer defined to avoid collisions when linking statically
* Mon Oct 28 2013 prusnak@opensuse.org
- add SDL2 provides
* Tue Aug 13 2013 jengelh@inai.de
- Some metadata spruce-up: add current URLs, softer wildcarding
  in the files list, more robust make install call
- Reduce build dependencies
- Optional signature verification in local builds
* Tue Aug 13 2013 prusnak@opensuse.org
- created package (version 2.0.0) - based on SDL package
